@@ -4,7 +4,7 @@ use anyhow::Result;
 use arti_rpcserver::RpcMgr;
 use derive_builder::Builder;
 use fs_mistrust::Mistrust;
-use futures::{AsyncReadExt, stream::StreamExt, task::SpawnExt};
+use futures::{AsyncReadExt, stream::StreamExt};
 use listener::{RpcListenerMap, RpcListenerMapBuilder};
 use serde::{Deserialize, Serialize};
 use session::ArtiRpcSession;
@@ -14,7 +14,7 @@ use tor_config_path::CfgPathResolver;
 use tracing::{debug, info};
 
 use arti_client::TorClient;
-use tor_rtcompat::{NetStreamListener as _, Runtime, general};
+use tor_rtcompat::{NetStreamListener as _, Runtime, SpawnExt, general};
 
 pub(crate) mod conntarget;
 pub(crate) mod listener;
@@ -223,7 +223,7 @@ mod test {
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
     #![allow(clippy::unwrap_used)]
-    #![allow(clippy::unchecked_duration_subtraction)]
+    #![allow(clippy::unchecked_time_subtraction)]
     #![allow(clippy::useless_vec)]
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
