@@ -8,6 +8,8 @@ use crate::factory::BootstrapReporter;
 use async_trait::async_trait;
 use futures::future::Shared;
 use oneshot_fused_workaround as oneshot;
+#[cfg(feature = "relay")]
+use safelog::Sensitive;
 use std::result::Result as StdResult;
 use std::sync::Arc;
 use std::time::Duration;
@@ -90,7 +92,7 @@ pub(crate) trait AbstractChannelFactory {
     #[cfg(feature = "relay")]
     async fn build_channel_using_incoming(
         &self,
-        peer: std::net::SocketAddr,
+        peer: Sensitive<std::net::SocketAddr>,
         stream: Self::Stream,
         memquota: ChannelAccount,
     ) -> Result<Arc<Self::Channel>>;
@@ -163,7 +165,7 @@ impl<CF: AbstractChannelFactory + Clone> AbstractChanMgr<CF> {
     #[cfg(feature = "relay")]
     pub(crate) async fn handle_incoming(
         &self,
-        src: std::net::SocketAddr,
+        src: Sensitive<std::net::SocketAddr>,
         stream: CF::Stream,
     ) -> Result<Arc<CF::Channel>> {
         let chan_builder = self.channels.builder();
@@ -205,6 +207,7 @@ impl<CF: AbstractChannelFactory + Clone> AbstractChanMgr<CF> {
 
     /// Get a channel whose identity is `ident` - internal implementation
     #[allow(clippy::cognitive_complexity)]
+    #[instrument(skip_all, level = "trace")]
     async fn get_or_launch_internal(
         &self,
         target: CF::BuildSpec,
@@ -339,6 +342,7 @@ impl<CF: AbstractChannelFactory + Clone> AbstractChanMgr<CF> {
     /// instead return `Ok(None)`.  (We could instead have the caller detect
     /// such actions, but it's less efficient to construct them, insert them,
     /// and immediately revert them.)
+    #[instrument(skip_all, level = "trace")]
     fn choose_action(
         &self,
         target: &CF::BuildSpec,
@@ -455,7 +459,7 @@ mod test {
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
     #![allow(clippy::unwrap_used)]
-    #![allow(clippy::unchecked_duration_subtraction)]
+    #![allow(clippy::unchecked_time_subtraction)]
     #![allow(clippy::useless_vec)]
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
@@ -608,7 +612,7 @@ mod test {
         #[cfg(feature = "relay")]
         async fn build_channel_using_incoming(
             &self,
-            _peer: std::net::SocketAddr,
+            _peer: Sensitive<std::net::SocketAddr>,
             _stream: Self::Stream,
             _memquota: ChannelAccount,
         ) -> Result<Arc<Self::Channel>> {
