@@ -30,7 +30,7 @@
 #![deny(clippy::ref_option_ref)]
 #![warn(clippy::semicolon_if_nothing_returned)]
 #![warn(clippy::trait_duplication_in_bounds)]
-#![deny(clippy::unchecked_duration_subtraction)]
+#![deny(clippy::unchecked_time_subtraction)]
 #![deny(clippy::unnecessary_wraps)]
 #![warn(clippy::unseparated_literal_suffix)]
 #![deny(clippy::unwrap_used)]
@@ -73,7 +73,7 @@ use futures::io::{
 use memchr::memchr;
 use std::sync::Arc;
 use std::time::Duration;
-use tracing::info;
+use tracing::{info, instrument};
 
 pub use err::{Error, RequestError, RequestFailedError};
 pub use response::{DirResponse, SourceInfo};
@@ -110,6 +110,7 @@ pub enum AnonymizedRequest {
 ///
 /// This is the only function in this crate that knows about CircMgr and
 /// DirInfo.  Perhaps this function should move up a level into DirMgr?
+#[instrument(level = "trace", skip_all)]
 pub async fn get_resource<CR, R, SP>(
     req: &CR,
     dirinfo: DirInfo<'_>,
@@ -532,15 +533,14 @@ mod test {
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
     #![allow(clippy::unwrap_used)]
-    #![allow(clippy::unchecked_duration_subtraction)]
+    #![allow(clippy::unchecked_time_subtraction)]
     #![allow(clippy::useless_vec)]
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
     use super::*;
     use tor_rtmock::io::stream_pair;
 
-    #[allow(deprecated)] // TODO #1885
-    use tor_rtmock::time::MockSleepProvider;
+    use tor_rtmock::simple_time::SimpleMockTimeProvider;
 
     use futures_await_test::async_test;
 
@@ -581,7 +581,7 @@ mod test {
         // We don't need to do anything fancy here, since we aren't simulating
         // a timeout.
         #[allow(deprecated)] // TODO #1885
-        let mock_time = MockSleepProvider::new(std::time::SystemTime::now());
+        let mock_time = SimpleMockTimeProvider::from_wallclock(std::time::SystemTime::now());
 
         let mut output = Vec::new();
         let mut stream = match get_decoder(data, encoding, AnonymizedRequest::Direct) {
