@@ -28,7 +28,7 @@ use std::result::Result as StdResult;
 use std::sync::Arc;
 use std::time::SystemTime;
 
-use rusqlite::{params, OpenFlags, OptionalExtension, Transaction};
+use rusqlite::{OpenFlags, OptionalExtension, Transaction, params};
 use time::OffsetDateTime;
 use tracing::{trace, warn};
 
@@ -538,7 +538,11 @@ impl Store for SqliteStore {
         }
     }
     fn upgrade_to_readwrite(&mut self) -> Result<bool> {
-        if self.is_readonly() && self.sql_path.is_some() {
+        let Some(sql_path) = self.sql_path.as_ref() else {
+            return Ok(true);
+        };
+
+        if self.is_readonly() {
             let lf = self
                 .lockfile
                 .as_mut()
@@ -547,9 +551,7 @@ impl Store for SqliteStore {
                 // Somebody else has the lock.
                 return Ok(false);
             }
-            // Unwrap should be safe due to parent `.is_some()` check
-            #[allow(clippy::unwrap_used)]
-            match rusqlite::Connection::open(self.sql_path.as_ref().unwrap()) {
+            match rusqlite::Connection::open(sql_path) {
                 Ok(conn) => {
                     self.conn = conn;
                 }
@@ -1429,7 +1431,7 @@ pub(crate) mod test {
     use crate::storage::EXPIRATION_DEFAULTS;
     use digest::Digest;
     use hex_literal::hex;
-    use tempfile::{tempdir, TempDir};
+    use tempfile::{TempDir, tempdir};
     use time::ext::NumericalDuration;
     use tor_llcrypto::d::Sha3_256;
 
@@ -1644,19 +1646,25 @@ pub(crate) mod test {
             );
             assert!(store.consensus_by_meta(&cmeta3).is_err());
 
-            assert!(store
-                .consensus_by_sha3_digest_of_signed_part(&[0x99; 32])?
-                .is_none());
+            assert!(
+                store
+                    .consensus_by_sha3_digest_of_signed_part(&[0x99; 32])?
+                    .is_none()
+            );
         }
 
         {
-            assert!(store
-                .consensus_by_sha3_digest_of_signed_part(&[0xAB; 32])?
-                .is_some());
+            assert!(
+                store
+                    .consensus_by_sha3_digest_of_signed_part(&[0xAB; 32])?
+                    .is_some()
+            );
             store.delete_consensus(&cmeta)?;
-            assert!(store
-                .consensus_by_sha3_digest_of_signed_part(&[0xAB; 32])?
-                .is_none());
+            assert!(
+                store
+                    .consensus_by_sha3_digest_of_signed_part(&[0xAB; 32])?
+                    .is_none()
+            );
         }
 
         Ok(())
