@@ -185,7 +185,7 @@ impl FromStr for HsClientNickname {
 ///
 /// See the [module-level documentation](self) for more details.
 #[derive(Debug, Clone, Builder, Eq, PartialEq, Getters)]
-#[builder(build_fn(error = "ConfigBuildError", name = "build_unvalidated"))]
+#[builder(build_fn(private, error = "ConfigBuildError", name = "build_unvalidated"))]
 #[builder(derive(Serialize, Deserialize, Debug, Deftly))]
 #[non_exhaustive]
 pub struct RestrictedDiscoveryConfig {
@@ -404,7 +404,7 @@ mod test {
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
     #![allow(clippy::unwrap_used)]
-    #![allow(clippy::unchecked_duration_subtraction)]
+    #![allow(clippy::unchecked_time_subtraction)]
     #![allow(clippy::useless_vec)]
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
