@@ -67,6 +67,8 @@
 // For key internal documentation about the data structure, see the doc comment for
 // `struct State` (down in the middle of the file).
 
+#![forbid(unsafe_code)] // if you remove this, enable (or write) miri tests (git grep miri)
+
 use crate::internal_prelude::*;
 
 use IfEnabled::*;
@@ -75,7 +77,7 @@ mod bookkeeping;
 mod reclaim;
 mod total_qty_notifier;
 
-#[cfg(all(test, feature = "memquota"))]
+#[cfg(all(test, feature = "memquota", not(miri) /* coarsetime */))]
 pub(crate) mod test;
 
 use bookkeeping::{BookkeepableQty, ClaimedQty, ParticipQty, TotalQty};
@@ -112,6 +114,11 @@ pub struct MemoryQuotaTracker {
 /// An `Account` is a handle.  All clones refer to the same underlying conceptual Account.
 ///
 /// `Account`s are created using [`MemoryQuotaTracker::new_account`].
+///
+/// # Use in Arti
+///
+/// In Arti, we usually use a newtype around `Account`, rather than a bare `Account`.
+/// See `tor_proto::memquota`.
 #[derive(Educe)]
 #[educe(Debug)]
 pub struct Account(IfEnabled<AccountInner>);
@@ -282,7 +289,7 @@ pub enum Reclaimed {
 
 //---------- principal data structure ----------
 
-slotmap::new_key_type! {
+slotmap_careful::new_key_type! {
     /// Identifies an Account
     ///
     /// After an account is torn down, the `AId` becomes invalid
@@ -541,8 +548,10 @@ impl MemoryQuotaTracker {
             return Ok(MemoryQuotaTracker::new_noop());
         };
 
-        let (reclaim_tx, reclaim_rx) = mpsc::channel(0 /* plus num_senders, ie 1 */);
+        let (reclaim_tx, reclaim_rx) =
+            mpsc_channel_no_memquota(0 /* plus num_senders, ie 1 */);
         let total_used = TotalQtyNotifier::new_zero(reclaim_tx);
+        let ConfigInner { max, low_water } = config; // for logging
 
         let global = Global {
             total_used,
@@ -559,6 +568,8 @@ impl MemoryQuotaTracker {
         let for_task = Arc::downgrade(&tracker);
         runtime.spawn(reclaim::task(for_task, reclaim_rx, enabled))?;
 
+        info!(%max, %low_water, "Memory quota tracking initialised");
+
         Ok(tracker)
     }
 
@@ -634,6 +645,10 @@ impl MemoryQuotaTracker {
     /// Make a new `Account`
     ///
     /// To actually record memory usage, a Participant must be added.
+    ///
+    /// At most call sites, take an `Account` rather than a `MemoryQuotaTracker`,
+    /// and use [`Account::new_child()`].
+    /// That improves the ability to manage the hierarchy of Participants.
     //
     // Right now, parent can't be changed after construction of an Account,
     // so circular accounts are impossible.
@@ -909,6 +924,17 @@ impl Account {
         Ok(Ok((particip, xdata)))
     }
 
+    /// Obtain a new `Account` which is a child of this one
+    ///
+    /// Equivalent to
+    /// [`MemoryQuotaTracker.new_account`](MemoryQuotaTracker::new_account)`(Some(..))`
+    pub fn new_child(&self) -> crate::Result<Self> {
+        let Enabled(self_, _enabled) = &self.0 else {
+            return Ok(Account::new_noop());
+        };
+        self_.tracker.new_account(Some(self))
+    }
+
     /// Obtains a handle for the `MemoryQuotaTracker`
     pub fn tracker(&self) -> Arc<MemoryQuotaTracker> {
         let Enabled(self_, _enabled) = &self.0 else {
@@ -928,6 +954,13 @@ impl Account {
         };
         WeakAccount(Enabled(inner, *enabled))
     }
+
+    /// Obtain a new `Account` that does nothing and has no associated tracker
+    ///
+    /// All methods on this succeed, but they don't do anything.
+    pub fn new_noop() -> Self {
+        Account(IfEnabled::Noop)
+    }
 }
 
 impl Clone for Account {
@@ -1064,10 +1097,31 @@ impl Participation {
 
     /// Record that some memory has been (or will be) allocated (using `Qty`)
     pub(crate) fn claim_qty(&mut self, want: Qty) -> crate::Result<()> {
+        self.claim_qty_inner(want)
+            .inspect_err(|e| trace_report!(e, "claim {}", want))
+    }
+
+    /// Record that some memory has been (or will be) allocated - core implementation
+    ///
+    /// Caller must handles trace logging.
+    fn claim_qty_inner(&mut self, want: Qty) -> crate::Result<()> {
         let Enabled(self_, enabled) = &mut self.0 else {
             return Ok(());
         };
 
+        // In debug builds, check that the Account is still live, to detect lifetime trouble
+        // (we repeat this later, which is OK in a debug build)
+        #[cfg(debug_assertions)]
+        {
+            find_in_tracker! {
+                enabled;
+                self_.tracker => + tracker, state;
+                self_.aid => _arecord;
+                *self_.pid => _precord;
+                ?Error
+            };
+        }
+
         if let Some(got) = self_.cache.split_off(want) {
             return got.claim_return_to_participant();
         }
