@@ -1,6 +1,6 @@
 //! Handle the middle document of an onion service descriptor.
 
-use once_cell::sync::Lazy;
+use std::sync::LazyLock;
 use subtle::ConstantTimeEq;
 use tor_hscrypto::pk::{HsBlindId, HsClientDescEncSecretKey, HsSvcDescEncKey};
 use tor_hscrypto::{RevisionCounter, Subcredential};
@@ -13,10 +13,10 @@ use crate::parse::{keyword::Keyword, parser::SectionRules};
 use crate::types::misc::B64;
 use crate::{Pos, Result};
 
-use super::desc_enc::{
-    HsDescEncNonce, HsDescEncryption, HS_DESC_CLIENT_ID_LEN, HS_DESC_ENC_NONCE_LEN, HS_DESC_IV_LEN,
-};
 use super::HsDescError;
+use super::desc_enc::{
+    HS_DESC_CLIENT_ID_LEN, HS_DESC_ENC_NONCE_LEN, HS_DESC_IV_LEN, HsDescEncNonce, HsDescEncryption,
+};
 
 /// The only currently recognized `desc-auth-type`.
 //
@@ -30,7 +30,7 @@ pub(super) const HS_DESC_AUTH_TYPE: &str = "x25519";
 pub(super) struct HsDescMiddle {
     /// A public key used by authorized clients to decrypt the key used to
     /// decrypt the encryption layer and decode the inner document.  This is
-    /// ignored if client authorization is not in use.
+    /// ignored if restricted discovery is not in use.
     ///
     /// This is `KP_hss_desc_enc`, and appears as `desc-auth-ephemeral-key` in
     /// the document format; It is used along with `KS_hsc_desc_enc` to perform
@@ -128,7 +128,8 @@ impl HsDescMiddle {
 /// service descriptor.
 #[derive(Debug, Clone)]
 pub(super) struct AuthClient {
-    /// A check field that clients can use to see if this [`AuthClient`] entry corresponds to a key they hold.
+    /// A check field that clients can use to see if this [`AuthClient`] entry corresponds
+    /// to a key they hold.
     ///
     /// This is the first part of the `auth-client` line.
     pub(super) client_id: CtByteArray<HS_DESC_CLIENT_ID_LEN>,
@@ -176,7 +177,7 @@ decl_keyword! {
 
 /// Rules about how keywords appear in the middle document of an onion service
 /// descriptor.
-static HS_MIDDLE_RULES: Lazy<SectionRules<HsMiddleKwd>> = Lazy::new(|| {
+static HS_MIDDLE_RULES: LazyLock<SectionRules<HsMiddleKwd>> = LazyLock::new(|| {
     use HsMiddleKwd::*;
 
     let mut rules = SectionRules::builder();
@@ -194,7 +195,7 @@ impl HsDescMiddle {
     /// string.
     #[cfg_attr(feature = "hsdesc-inner-docs", visibility::make(pub))]
     pub(super) fn parse(s: &str) -> Result<HsDescMiddle> {
-        let mut reader = NetDocReader::new(s);
+        let mut reader = NetDocReader::new(s)?;
         let result = HsDescMiddle::take_from_reader(&mut reader).map_err(|e| e.within(s))?;
         Ok(result)
     }
@@ -254,7 +255,7 @@ mod test {
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
     #![allow(clippy::unwrap_used)]
-    #![allow(clippy::unchecked_duration_subtraction)]
+    #![allow(clippy::unchecked_time_subtraction)]
     #![allow(clippy::useless_vec)]
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
