@@ -21,7 +21,7 @@ impl UniqId {
         // Relaxed ordering is fine; we don't care about how this
         // is instantiated with respect to other channels.
         let id = NEXT_ID.fetch_add(1, Ordering::Relaxed);
-        assert!(id != std::usize::MAX, "Exhausted the channel ID namespace");
+        assert!(id != usize::MAX, "Exhausted the channel ID namespace");
         UniqId(id)
     }
 }
@@ -70,7 +70,7 @@ mod test {
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
     #![allow(clippy::unwrap_used)]
-    #![allow(clippy::unchecked_duration_subtraction)]
+    #![allow(clippy::unchecked_time_subtraction)]
     #![allow(clippy::useless_vec)]
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
