@@ -52,8 +52,8 @@ use std::collections::HashMap;
 use std::pin::Pin;
 use std::sync::Arc;
 
-use futures::future::BoxFuture;
 use futures::Sink;
+use futures::future::BoxFuture;
 
 use tor_error::internal;
 use void::Void;
@@ -312,7 +312,7 @@ pub struct InvokerEnt {
     ///
     /// Always present.
     #[doc(hidden)]
-    pub invoker: &'static (dyn Invocable),
+    pub invoker: &'static dyn Invocable,
 
     /// The same function as `invoker`, but only if that function implements
     /// `RpcInvocable`
@@ -320,7 +320,7 @@ pub struct InvokerEnt {
     /// This will be `None` if this is a "special" method--that is, one whose inputs and outputs are not serializable,
     /// and which is therefore not invocable directly from an RPC connection.
     #[doc(hidden)]
-    pub rpc_invoker: Option<&'static (dyn RpcInvocable)>,
+    pub rpc_invoker: Option<&'static dyn RpcInvocable>,
 
     // These fields are used to make sure that we aren't installing different
     // functions for the same (Object, Method) pair.
@@ -770,12 +770,12 @@ pub(crate) mod test {
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
     #![allow(clippy::unwrap_used)]
-    #![allow(clippy::unchecked_duration_subtraction)]
+    #![allow(clippy::unchecked_time_subtraction)]
     #![allow(clippy::useless_vec)]
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
 
-    use crate::{method::RpcMethod, templates::*, DispatchTable, InvokeError, Method, NoUpdates};
+    use crate::{DispatchTable, InvokeError, Method, NoUpdates, method::RpcMethod, templates::*};
     use derive_deftly::Deftly;
     use futures::SinkExt;
     use futures_await_test::async_test;
