@@ -1,5 +1,6 @@
-//! Functionality for working with Unix addresses.
+//! Functionality for working with AF\_UNIX addresses.
 
+#[cfg(unix)]
 use tor_general_addr::unix;
 
 /// Helper: construct an unnamed SocketAddr.
@@ -10,28 +11,33 @@ pub(crate) fn new_unnamed_socketaddr() -> std::io::Result<unix::SocketAddr> {
     unix::SocketAddr::from_pathname("")
 }
 
-/// Error: Tried to perform an operation on an unsupported kind of unix address.
+/// Error: Tried to perform an operation on an unsupported kind of AF\_UNIX address.
 ///
 /// (For example, you can't bind or connect to an unnamed address.)
 #[derive(Clone, Debug, thiserror::Error)]
 #[error("Operation not supported on this kind of AF_UNIX address")]
 #[non_exhaustive]
-pub struct UnsupportedUnixAddressType;
+pub struct UnsupportedAfUnixAddressType;
 
-impl From<UnsupportedUnixAddressType> for std::io::Error {
-    fn from(value: UnsupportedUnixAddressType) -> Self {
+/// Deprecated name for `UnsupportedAfUnixAddressType`
+#[deprecated]
+pub type UnsupportedUnixAddressType = UnsupportedAfUnixAddressType;
+
+impl From<UnsupportedAfUnixAddressType> for std::io::Error {
+    fn from(value: UnsupportedAfUnixAddressType) -> Self {
         std::io::Error::new(std::io::ErrorKind::Unsupported, value)
     }
 }
 
 #[cfg(test)]
 mod test {
+    #[cfg(unix)]
     use super::*;
 
     #[test]
     #[cfg(unix)]
     fn unnamed() {
-        let u = new_unnamed_socketaddr().expect("couldn't construct unnamed unix socketaddr");
+        let u = new_unnamed_socketaddr().expect("couldn't construct unnamed AF_UNIX socketaddr");
         assert!(u.is_unnamed());
         assert!(u.as_pathname().is_none());
 
