@@ -63,9 +63,9 @@ pub struct SleepFuture {
 ///
 /// Each sleep ([`Id`], [`SleepFuture`]) is in one of the following states:
 ///
-/// | state       | [`SleepFuture`]  | `futures`         | `unready`          |
+/// | state       | [`SleepFuture`]  | `futures`        | `unready`          |
 /// |-------------|------------------|------------------|--------------------|
-/// | UNPOLLLED   | exists           | present, `None`  | present, `> now`   |
+/// | UNPOLLED    | exists           | present, `None`  | present, `> now`   |
 /// | WAITING     | exists           | present, `Some`  | present, `> now`   |
 /// | READY       | exists           | present, `None`  | absent             |
 /// | DROPPED     | dropped          | absent           | absent             |
@@ -208,7 +208,7 @@ impl SleepProvider for Provider {
             prov: self.clone(),
         };
 
-        // This sleep is now UNPOLLLED, except that its time might be `<= now`:
+        // This sleep is now UNPOLLED, except that its time might be `<= now`:
 
         // Possibly, `until` isn't *strictly* after than `state.now`, since d might be 0.
         // If so, .wake_any() will restore the invariant by immediately waking.
@@ -300,16 +300,16 @@ mod test {
     #![allow(clippy::print_stdout)]
     #![allow(clippy::single_char_pattern)]
     #![allow(clippy::unwrap_used)]
-    #![allow(clippy::unchecked_duration_subtraction)]
+    #![allow(clippy::unchecked_time_subtraction)]
     #![allow(clippy::useless_vec)]
     #![allow(clippy::needless_pass_by_value)]
     //! <!-- @@ end test lint list maintained by maint/add_warning @@ -->
     use super::*;
     use crate::task::MockExecutor;
+    use Poll::*;
     use futures::poll;
     use humantime::parse_rfc3339;
-    use tor_rtcompat::BlockOn as _;
-    use Poll::*;
+    use tor_rtcompat::ToplevelBlockOn as _;
 
     fn ms(ms: u64) -> Duration {
         Duration::from_millis(ms)
